"use client";
import ProductRating from "@/components/shared/product-info/product-rating";
import { Button } from "@/components/ui/button";
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card";
import { ImageBaseUrl } from "@/configs/api";
import { Link } from "@/i18n/routing";
import { add } from "@/servers/actions/favorite-action";
import Cookies from "js-cookie";
import { Heart, Loader2 } from "lucide-react";
import { useLocale, useTranslations } from "next-intl";
import Image from "next/image";
import { useTransition } from "react";
import { toast } from "sonner";


function ProductCard({ product, refetch }: { product: any, refetch: any }) {
	const locale = useLocale();
	const t = useTranslations();

	const [isPending, startTransition] = useTransition();

	// Determine the image source with proper fallback
	const imagePath = product?.images?.[0]?.image_path;
	const imageSrc = imagePath ? `${ImageBaseUrl}${imagePath}` : "/default-image.png";
	const imageAlt = product?.images?.[0]?.name || "Product image";

	const handleToggleFavorite = async (product: any) => {
		const _session = Cookies.get("__t");

		if (!_session) {
			toast.error(t("Please login to add to favorite"));
			return;
		}

		startTransition(async () => {
			try {
				const result = await add(product?.id);
				if (result?.success) {
					const isFavorite = product?.is_favorite;
					toast.success(isFavorite ? t("Product removed from favorite") : t("Product added to favorite"), {
						style: { backgroundColor: "green", color: "white" },
					});

					await refetch();
				} else {
					toast.error(t(result?.message?.replace(".", "")));
				}
			} catch (error: any) {
				console.log("error: ", error);
				toast.error("Something went wrong");
			}
		});
	};


	return (
		<Card className="w-full h-[360px] overflow-hidden rounded-lg shadow-sm hover:shadow-md transition-shadow duration-200 relative">
			<Button
				variant="ghost"
				size="icon"
				className={`absolute top-2 right-2 bg-white/80 hover:bg-white rounded-full z-10 ${product?.is_favorite ? "text-red-500" : "text-gray-400 hover:text-red-500"}`}
				onClick={() => handleToggleFavorite(product)}
				disabled={isPending}
			>
				{isPending ? <Loader2 className="h-5 w-5 animate-spin" color="red" /> : <Heart className="h-5 w-5" fill={product?.is_favorite ? "currentColor" : "none"} />}
			</Button>
			<Link href={`/products/${product.product_slug}` as any} key={product.id}>
				<CardContent className="p-0">
					<Image
						src={imageSrc}
						alt={imageAlt}
						className="w-full h-48 object-cover"
						width={300}
						height={200}
					/>
				</CardContent>
				<CardHeader className="p-4">
					<CardTitle className="text-lg font-semibold text-center">{locale === "ar" ? product?.name_ar : product?.name_en}</CardTitle>
					{product?.brand && <span className="flex justify-center items-center text-gray-600 font-medium text-sm">
						العلامة التجارية: {locale === "ar" ? product?.brand?.name_ar : product?.brand?.name_en}
					</span>}
					<div className="my-2 mx-auto">
						<ProductRating rating={product?.rating} />
					</div>
					<CardDescription className="flex justify-center items-center gap-2 my-2">
						<Image src={"/coins/Saudi_Riyal.jpg"} alt="Saudi_Riyal" width={16} height={16} />
						<span className="text-blue-600 font-bold text-xl">{product?.base_price}</span>
					</CardDescription>
				</CardHeader>
			</Link>
		</Card>
	);
}

export default ProductCard;